==> edge-login-ui-rn-1.4.1.tgz: package/lib/components/modals/ListModal.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { FlatList, Keyboard } from 'react-native';
import { ModalCloseArrow, ModalMessage, ModalTitle } from '../themed/ModalParts';
import { OutlinedTextInput } from '../themed/OutlinedTextInput';
import { ThemedModal } from '../themed/ThemedModal';
import { GradientFadeOut } from './GradientFadeout';
export function ListModal(_a) {
    var { bridge, title, message, textInput = true, initialValue = '', rowsData = [], fullScreen = true, rowComponent, rowDataFilter, closeArrow = true, onSubmitEditing, onViewableItemsChanged } = _a, textProps = __rest(_a, ["bridge", "title", "message", "textInput", "initialValue", "rowsData", "fullScreen", "rowComponent", "rowDataFilter", "closeArrow", "onSubmitEditing", "onViewableItemsChanged"]);
    const [text, setText] = React.useState(initialValue);
    const renderItem = ({ item }) => rowComponent ? rowComponent(item) : null;
    const handleCancel = () => bridge.resolve(undefined);
    const handleChangeText = (text) => {
        setText(text);
    };
    const handleSubmitEditing = () => onSubmitEditing != null ? onSubmitEditing(text) : bridge.resolve(text);
    return (React.createElement(ThemedModal, { bridge: bridge, onCancel: handleCancel },
        title != null ? React.createElement(ModalTitle, null, title) : null,
        message != null ? React.createElement(ModalMessage, null, message) : null,
        textInput ? (React.createElement(OutlinedTextInput
        // Our props:
        , Object.assign({ 
            // Our props:
            searchIcon: true, blurOnClear: true, autoCorrect: false, autoCapitalize: "words", returnKeyType: "done", marginRem: [1, 0.5], onChangeText: handleChangeText, onSubmitEditing: handleSubmitEditing, value: text }, textProps))) : null,
        React.createElement(FlatList, { style: { flexGrow: fullScreen ? 1 : 0 }, data: rowsData, initialNumToRender: 12, onScroll: () => Keyboard.dismiss(), keyboardShouldPersistTaps: "handled", renderItem: renderItem, keyExtractor: (_, i) => `${i}`, onViewableItemsChanged: onViewableItemsChanged }),
        React.createElement(GradientFadeOut, null),
        closeArrow ? React.createElement(ModalCloseArrow, { onPress: handleCancel }) : null));
}

==> edge-login-ui-rn-2.12.0.tgz: package/lib/components/modals/ListModal.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { FlatList, Keyboard } from 'react-native';
import { useTheme } from '../services/ThemeContext';
import { ModalFooter, ModalMessage, ModalTitle } from '../themed/ModalParts';
import { OutlinedTextInput } from '../themed/OutlinedTextInput';
import { ThemedModal } from '../themed/ThemedModal';
import { GradientFadeOut } from './GradientFadeout';
export function ListModal(_a) {
    var { bridge, title, message, textInput = true, initialValue = '', rowsData = [], fullScreen = true, rowComponent, rowDataFilter, closeArrow = true, onSubmitEditing, onViewableItemsChanged } = _a, textProps = __rest(_a, ["bridge", "title", "message", "textInput", "initialValue", "rowsData", "fullScreen", "rowComponent", "rowDataFilter", "closeArrow", "onSubmitEditing", "onViewableItemsChanged"]);
    const theme = useTheme();
    const [text, setText] = React.useState(initialValue);
    const renderItem = ({ item }) => rowComponent ? rowComponent(item) : null;
    const handleCancel = () => bridge.resolve(undefined);
    const handleChangeText = (text) => {
        setText(text);
    };
    const handleSubmitEditing = () => onSubmitEditing != null ? onSubmitEditing(text) : bridge.resolve(text);
    const scrollPadding = React.useMemo(() => {
        return { paddingBottom: theme.rem(ModalFooter.bottomRem) };
    }, [theme]);
    return (React.createElement(ThemedModal, { bridge: bridge, onCancel: handleCancel },
        title != null ? React.createElement(ModalTitle, null, title) : null,
        message != null ? React.createElement(ModalMessage, null, message) : null,
        textInput ? (React.createElement(OutlinedTextInput
        // Our props:
        , Object.assign({ 
            // Our props:
            searchIcon: true, blurOnClear: true, autoCorrect: false, autoCapitalize: "words", returnKeyType: "done", marginRem: [1, 0.5], onChangeText: handleChangeText, onSubmitEditing: handleSubmitEditing, value: text }, textProps))) : null,
        React.createElement(FlatList, { contentContainerStyle: scrollPadding, data: rowsData, initialNumToRender: 12, onScroll: () => Keyboard.dismiss(), keyboardShouldPersistTaps: "handled", renderItem: renderItem, keyExtractor: (_, i) => `${i}`, onViewableItemsChanged: onViewableItemsChanged }),
        React.createElement(GradientFadeOut, null),
        !closeArrow ? null : React.createElement(ModalFooter, { onPress: handleCancel, fadeOut: true })));
}
